@@ -2,11 +2,11 @@ import sys
 
 sys.path.append('')
 
-from common.module import BaseUtil, RedisUtil
+from elf_py_utils import BaseUtil, redis_util
 
 logger = BaseUtil.set_logging('RedisCMD')
 
-redis = RedisUtil.connect_redis()
+redis = redis_util.connect_redis()
 
 
 def redis_get(param: str):
